==> mobot-0.1.0-py3-none-any.whl: mobot/_tests/camera_test.py <==
# MIT License
#
# Copyright (c) 2021 Mobotx
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import numpy as np
from mobot.brain.agent import Agent
from mobot.utils.image_grid import ImageGrid

class CameraTestAgent(Agent):
    def __init__(self):
        Agent.__init__(self)
        self.seq = 0
        self.camera.register_callback(self.camera_cb)
        self.image_grid = ImageGrid(self)

    def camera_cb(self, image, metadata):
        self.seq += 1
        print(f"Frame {self.seq}")
        self.image_grid.new_image(image)

def main():
    camera_test_agent = CameraTestAgent()
    camera_test_agent.start()

if __name__ == "__main__":
    main()

==> mobot-0.1.2-py3-none-any.whl: mobot/_tests/camera_test.py <==
# MIT License
#
# Copyright (c) 2021 Mobotx
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import numpy as np

from mobot.brain.agent import Agent


class CameraTestAgent(Agent):

    def __init__(self):
        super().__init__()
        self.seq = 0
        self.camera.register_callback(self.camera_cb)

    def camera_cb(self, image, metadata):
        self.seq += 1
        print(f"Frame {self.seq} of shape {image.shape}")


def main():
    camera_test_agent = CameraTestAgent()
    camera_test_agent.start()


if __name__ == "__main__":
    main()
